@@ -120,7 +120,7 @@ ItemManager.method("set_from_obj", function(arg)
 
 ItemManager.method("call_with_item_div", function(inserter, when_created)
 {
-  inserter('<div id="item_[id]" class="item"></div>'.replace('[id]', this.id));
+  inserter('<div id="item_[id]" class="item ui-corner-all"></div>'.replace('[id]', this.id));
   this.div = $("#item_"+this.id);
 
   if (when_created != undefined)
@@ -135,14 +135,11 @@ ItemManager.method("fill_item_div", function()
 {
   var self = this;
 
-  var have_dropzone = false;
   if (self.id == null)
   {
-    have_dropzone = true;
     self.div.html(
       (
-      '<div id="item_dropzone_[id]" class="dropzone">Drop here</div>'+
-      '<div class="editcontrols">'+
+      '<div class="editcontrols ui-corner-all">'+
       '<span id="item_cursor_[id]" class="cursorfield">&nbsp;</span> '+
       '<input type="button" id="new_[id]" value="New" class="editbutton"/>'+
       '</div>'
@@ -154,20 +151,14 @@ ItemManager.method("fill_item_div", function()
   {
     if (self.manager.view_time == null)
     {
-      have_dropzone = true;
       self.div.html(
         (
-        '<div id="item_dropzone_[id]" class="dropzone">Drop here</div>'+
-        '<div class="editcontrols">'+
+        '<div class="editcontrols ui-corner-all item-drag-handle">'+
         '<span id="item_cursor_[id]" class="cursorfield">&nbsp;</span> '+
         '<span id="item_collapser_[id]" class="collapser">&nbsp;</span> '+
         '<input type="button" id="edit_[id]" value="Edit" class="editbutton"/> '+
         '<input type="button" id="delete_[id]" value="Delete" class="deletebutton"/> '+
-        '<div id="item_draghandle_[id]" class="draghandle">'+
-          '<img src="/static/dragger.png" alt="drag handle" '+
-          'title="Drag this handle to change display order"/>'+
-        '</div> '+
-        'Tags: [tags]'+
+        ' [tags]'+
         '</div>'+
         '<div id="item_contents_[id]" class="itemcontents">[contents]</div>'
         ).allreplace('[id]', self.id)
@@ -176,18 +167,6 @@ ItemManager.method("fill_item_div", function()
         );
       $('#edit_'+self.id).click(function(){ self.begin_edit() });
       $('#delete_'+self.id).click(function(){ self.do_delete() });
-      $('#item_draghandle_'+self.id).draggable({
-          helper: "clone",
-          start: function() 
-          { 
-            self.manager.dragging_item = self; 
-            self.div.addClass("dragging");
-          },
-          stop: function() 
-          { 
-            self.div.removeClass("dragging");
-          }
-          });
     }
     else
     {
@@ -252,47 +231,6 @@ ItemManager.method("fill_item_div", function()
         function() { item_toggle_collapsed(self.div); }
         );
   }
-
-  if (have_dropzone)
-  {
-    $("#item_dropzone_"+self.id).droppable({
-      accept: ".draghandle",
-      activeClass: 'dropzone-active',
-      hoverClass:  'dropzone-hover',
-      tolerance: 'pointer',
-      drop: function(ev, ui) {
-        var dragged_item = self.manager.dragging_item;
-        if (self == dragged_item)
-          return;
-
-        // move dragged item's div in front of ours
-        dragged_item.div.hide("slow",
-          function()
-          {
-            dragged_item.div.remove();
-            dragged_item.call_with_item_div(
-              function(html) { self.div.before(html); } /* creator */
-              );
-            self.manager.set_cursor_to(dragged_item.div);
-          });
-
-        // report drag to server
-        $.ajax({
-          type: 'POST',
-          dataType: 'text',
-          url: 'item/reorder',
-          data: {
-            json: JSON.stringify({
-              dragged_item: dragged_item.id,
-              before_item: self.id,
-              current_search: $("#search").val()
-            })},
-          error: function(req, stat, err) 
-          { report_error("Reordering failed on server."); }
-        });
-      }
-      });
-  }
 });
 
 
@@ -315,20 +253,17 @@ ItemManager.method("begin_edit", function()
 
   self.div.html(
     (
-    '<div id="edit_div_[id]" class="edit_div">'+
-    '<table>'+
-    '<tr><td>'+
+    '<div class="editcontrols ui-corner-all">'+
     '<input type="button"  id="edit_ok_[id]"  value="OK"  accesskey="o">&nbsp;'+
     '<input type="button" id="edit_cancel_[id]" value="Cancel" accesskey="c">&nbsp;'+
-    '<label for="edit_tags_[id]" accesskey="t">Tags: </label><input id="edit_tags_[id]" type="text" size="50"/>'+
-    '</td></tr>'+
-    '<tr><td>'+
+    '<input id="edit_tags_[id]" type="text" size="50"/>'+
+    '</div>'+
+    '<div class="itemcontents">'+
     '<textarea id="editor_[id]" cols="80"></textarea>'+
-    '</td></tr>'+
-    '</tr></table>'+
     '</div>'
     ).allreplace("[id]",  self.id)
     );
+  self.div.addClass("editing");
 
   // default to current search tags
   if (self.id == null)
@@ -357,7 +292,8 @@ ItemManager.method("begin_edit", function()
       */
 
   $("#edit_ok_"+self.id).click(function(){
-    $("edit_div_"+self.id).html(busy('Saving...'));
+    self.div.removeClass("editing");
+
     var tags = parse_tags($("#edit_tags_"+self.id).val());
 
     for (var i = 0; i<tags.length; ++i)
@@ -403,6 +339,8 @@ ItemManager.method("begin_edit", function()
   });
 
   $("#edit_cancel_"+self.id).click(function(){
+    self.div.removeClass("editing");
+
     self.fill_item_div();
     self.manager.redraw_cursor();
   });
@@ -486,7 +424,7 @@ ItemCollectionManager.method("set_history_slider", function(time)
       / (this.tsrange.max-this.tsrange.min)* 100.;
 
   ++this.slider_update_inhibitions;
-  $("#history_slider").slider("moveTo", new_percentage);
+  $("#history_slider").slider("value", new_percentage);
   --this.slider_update_inhibitions;
 });
 
@@ -536,7 +474,7 @@ ItemCollectionManager.method("setup_history_handling", function()
             self.set_time(new_time, "slider");
           }
         },
-      startValue: 100
+      value: 100
       });
 
   // setup history datepicker
@@ -797,10 +735,10 @@ ItemCollectionManager.method("set_cursor_to", function(div, is_up, noscroll)
 {
   if (this.cursor_at != null)
   {
-    this.cursor_at.find(".editcontrols").removeClass("hascursor");
+    this.cursor_at.removeClass("focused");
   }
 
-  div.find(".editcontrols").addClass("hascursor");
+  div.addClass("focused");
   if (!noscroll)
     div.get(0).scrollIntoView(is_up);
   this.cursor_at = div;
@@ -927,7 +865,7 @@ ItemCollectionManager.method("update", function(force)
 
 ItemCollectionManager.method("fill", function(query, timestamp, force)
 {
-  if ($(".item .edit_div").length != 0)
+  if ($(".item .editing").length != 0)
   {
     if (confirm("You seem to be editing one or more entries. Continue loading?") == false)
       return;
@@ -1232,7 +1170,35 @@ $(document).ready(function()
   var collection_manager = new ItemCollectionManager()
   document.collection_manager = collection_manager;
 
-  $("#navtabs > ul").tabs();
+  $("#navtabs").tabs();
+
+  $("#items").sortable({ 
+    handle: ".item-drag-handle",
+    start: function(event, ui) 
+      { $("#item_null").appendTo("#hiddenitems"); },
+    stop: function(event, ui) 
+      { $("#item_null").appendTo("#items"); },
+    update: function(event, ui)
+      {
+        var items = $("#items").children()
+        var item_ids = [];
+        for (var i = 0; i < items.length; ++i)
+          item_ids.push(items[i].id.replace("item_", ""));
+
+        $.ajax({
+          type: 'POST',
+          dataType: 'text',
+          url: 'item/reorder',
+          data: {
+            json: JSON.stringify({
+              new_order: item_ids.join(","),
+              current_search: $("#search").val()
+            })},
+          error: function(req, stat, err) 
+          { report_error("Reordering failed on server."); }
+        });
+      }
+    });
 
   update_main_tag_cloud();
   $("#chk_tagcloud_show_hidden").change(update_main_tag_cloud);
